Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConsoleOutput ¶
type ConsoleOutput struct {
}
func (*ConsoleOutput) ExecuteFile ¶
func (c *ConsoleOutput) ExecuteFile(path string, content []byte) error
ExecuteFile implements Output.
func (*ConsoleOutput) Finalize ¶
func (c *ConsoleOutput) Finalize() error
Finalize implements Output.
type FileOutput ¶
type FileOutput struct {
// contains filtered or unexported fields
}
func (*FileOutput) ExecuteFile ¶
func (fo *FileOutput) ExecuteFile(path string, content []byte) error
ExecuteFile implements Output.
type GitOutput ¶
type GitOutput struct {
// contains filtered or unexported fields
}
func (*GitOutput) ExecuteFile ¶
ExecuteFile implements Output.
type Output ¶
type Output interface {
// Initialize configured file system preparing it to accept files to write
Init() error
// Takes output content and writes it to destination at path
ExecuteFile(path string, content []byte) error
// Finalizes filesystem and cleans up any necessary resources
Finalize() error
}
Click to show internal directories.
Click to hide internal directories.